@@ -24,35 +24,31 @@ import java.util.Locale;
 import org.apache.uima.internal.util.I18nUtil;
 
 /**
- * The <code>InternationalizedException</code> class adds internationalization
- * support to the standard functionality provided by
- * <code>java.lang.Exception</code>.
+ * The <code>InternationalizedException</code> class adds internationalization support to 
+ * the standard functionality provided by <code>java.lang.Exception</code>.
  * <p>
- * To support internationalization, the thrower of an exception must not specify
- * a hardcoded message string. Instead, the thrower specifies a key that
- * identifies the message. That key is then looked up in a locale-specific
- * {@link java.util.ResourceBundle ResourceBundle} to find the actual message
- * associated with this exception.
+ * To support internationalization, the thrower of an exception must not specify a hardcoded message 
+ * string. Instead, the thrower specifies a key that identifies the message. That key is then looked 
+ * up in a locale-specific {@link java.util.ResourceBundle ResourceBundle} to find the actual 
+ * message associated with this exception.
  * <p>
- * This class also supports arguments to messages. The full message will be
- * constructed using the {@link java.text.MessageFormat MessageFormat} class.
- * For more information on internationalization, see the <a
- * href="http://java.sun.com/j2se/1.4/docs/guide/intl/index.html"> Java
- * Internationalization Guide</a>.
+ * This class also supports arguments to messages. The full message will be constructed using the 
+ * {@link java.text.MessageFormat MessageFormat} class. For more information on 
+ * internationalization, see the <a href="http://java.sun.com/j2se/1.4/docs/guide/intl/index.html">
+ * Java Internationalization Guide</a>.
  * <p>
- * This version of this class works with JDK versions prior to 1.4, since it
- * does not assume support for exception chaining. The file
- * <code>InternationalizedException.java_1_4</code> is a version that uses the
- * exception chaining support built-in to JDK1.4.
+ * This version of this class works with JDK versions prior to 1.4, since it does not assume support 
+ * for exception chaining. The file <code>InternationalizedException.java_1_4</code> is a version 
+ * that uses the exception chaining support built-in to JDK1.4.
  * 
  * 
  */
 public class InternationalizedException extends Exception {
+  
    private static final long serialVersionUID = 2306587442280738385L;
 
    /**
-    * The base name of the resource bundle in which the message for this
-    * exception is located.
+    * The base name of the resource bundle in which the message for this exception is located.
     */
    private String mResourceBundleName;
 
@@ -63,8 +59,8 @@ public class InternationalizedException extends Exception {
 
    /**
     * The arguments to this exception's message, if any. This allows an
-    * <code>InternationalizedException</code> to have a compound message, made
-    * up of multiple parts that are concatenated in a language-neutral way.
+    * <code>InternationalizedException</code> to have a compound message, made up of 
+    * multiple parts that are concatenated in a language-neutral way.
     */
    private Object[] mArguments;
 
@@ -75,8 +71,10 @@ public class InternationalizedException extends Exception {
    
    /**
     * the thread local class loader at creation time, see UIMA-4793
+    * Transient to allow exceptions to be serialized.
+    * Deserialized versions have null as their value, which is handled by the users
     */
-   final private ClassLoader originalContextClassLoader;
+   final transient private ClassLoader originalContextClassLoader;
 
    /**
     * Creates a new <code>InternationalizedException</code> with a null
@@ -87,31 +85,29 @@ public class InternationalizedException extends Exception {
    }
 
    /**
-    * Creates a new <code>InternationalizedException</code> with the specified
-    * cause and a null message.
+    * Creates a new <code>InternationalizedException</code> with the specified cause and a 
+    * null message.
     * 
     * @param aCause
-    *           the original exception that caused this exception to be thrown,
-    *           if any
+    *           the original exception that caused this exception to be thrown, if any
     */
    public InternationalizedException(Throwable aCause) {
       this(null, null, null, aCause);
    }
 
    /**
-    * Creates a new <code>InternationalizedException</code> with the specified
-    * message.
+    * Creates a new <code>InternationalizedException</code> with the specified message.
     * 
     * @param aResourceBundleName
-    *           the base name of the resource bundle in which the message for
-    *           this exception is located.
+    *           the base name of the resource bundle in which the message for this exception is 
+    *           located.
     * @param aMessageKey
-    *           an identifier that maps to the message for this exception. The
-    *           message may contain placeholders for arguments as defined by the
+    *           an identifier that maps to the message for this exception. The message may contain 
+    *           placeholders for arguments as defined by the 
     *           {@link java.text.MessageFormat MessageFormat} class.
     * @param aArguments
-    *           The arguments to the message. <code>null</code> may be used if
-    *           the message has no arguments.
+    *           The arguments to the message. <code>null</code> may be used if the message has no 
+    *           arguments.
     */
    public InternationalizedException(String aResourceBundleName,
          String aMessageKey, Object[] aArguments) {
@@ -119,69 +115,61 @@ public class InternationalizedException extends Exception {
    }
 
    /**
-    * Creates a new <code>InternationalizedException</code> with the specified
-    * message and cause.
+    * Creates a new <code>InternationalizedException</code> with the specified message and 
+    * cause.
     * 
     * @param aResourceBundleName
-    *           the base name of the resource bundle in which the message for
-    *           this exception is located.
+    *           the base name of the resource bundle in which the message for this exception is 
+    *           located.
     * @param aMessageKey
-    *           an identifier that maps to the message for this exception. The
-    *           message may contain placeholders for arguments as defined by the
+    *           an identifier that maps to the message for this exception. The message may contain 
+    *           placeholders for arguments as defined by the
     *           {@link java.text.MessageFormat MessageFormat} class.
     * @param aArguments
-    *           The arguments to the message. <code>null</code> may be used if
-    *           the message has no arguments.
+    *           The arguments to the message. <code>null</code> may be used if the message has no 
+    *           arguments.
     * @param aCause
-    *           the original exception that caused this exception to be thrown,
-    *           if any
+    *           the original exception that caused this exception to be thrown, if any
     */
-   public InternationalizedException(String aResourceBundleName,
-         String aMessageKey, Object[] aArguments, Throwable aCause) {
+   public InternationalizedException(String aResourceBundleName, String aMessageKey, 
+           Object[] aArguments, Throwable aCause) {
       super();
       originalContextClassLoader = Thread.currentThread().getContextClassLoader();
       mCause = aCause;
       mResourceBundleName = aResourceBundleName;
       mMessageKey = aMessageKey;
       mArguments = aArguments;
-      // if null message and mCause is Internationalized exception, "promote"
-      // message
+      // if null message and mCause is Internationalized exception, "promote" message
       if (mResourceBundleName == null && mMessageKey == null) {
          if (mCause instanceof InternationalizedException) {
-            mResourceBundleName = ((InternationalizedException) mCause)
-                  .getResourceBundleName();
+            mResourceBundleName = ((InternationalizedException) mCause).getResourceBundleName();
             mMessageKey = ((InternationalizedException) mCause).getMessageKey();
             mArguments = ((InternationalizedException) mCause).getArguments();
          } else if (mCause instanceof InternationalizedRuntimeException) {
-            mResourceBundleName = ((InternationalizedRuntimeException) mCause)
-                  .getResourceBundleName();
-            mMessageKey = ((InternationalizedRuntimeException) mCause)
-                  .getMessageKey();
-            mArguments = ((InternationalizedRuntimeException) mCause)
-                  .getArguments();
+            mResourceBundleName = ((InternationalizedRuntimeException) mCause).getResourceBundleName();
+            mMessageKey = ((InternationalizedRuntimeException) mCause).getMessageKey();
+            mArguments = ((InternationalizedRuntimeException) mCause).getArguments();
          }
       }
    }
 
    /**
-    * Gets the base name of the resource bundle in which the message for this
-    * exception is located.
+    * Gets the base name of the resource bundle in which the message for this exception is located.
     * 
-    * @return the resource bundle base name. May return <code>null</code> if
-    *         this exception has no message.
+    * @return the resource bundle base name. May return <code>null</code> if this exception has no 
+    * message.
     */
    public String getResourceBundleName() {
       return mResourceBundleName;
    }
 
    /**
-    * Gets the identifier for this exception's message. This identifier can be
-    * looked up in this exception's
-    * {@link java.util.ResourceBundle ResourceBundle} to get the locale-specific
-    * message for this exception.
+    * Gets the identifier for this exception's message. This identifier can be looked up in this 
+    * exception's {@link java.util.ResourceBundle ResourceBundle} to get the locale-specific message 
+    * for this exception.
     * 
-    * @return the resource identifier for this exception's message. May return
-    *         <code>null</code> if this exception has no message.
+    * @return the resource identifier for this exception's message. May return <code>null</code> if 
+    *         this exception has no message.
     */
    public String getMessageKey() {
       return mMessageKey;
@@ -189,8 +177,8 @@ public class InternationalizedException extends Exception {
 
    /**
     * Gets the arguments to this exception's message. Arguments allow a
-    * <code>InternationalizedException</code> to have a compound message, made
-    * up of multiple parts that are concatenated in a language-neutral way.
+    * <code>InternationalizedException</code> to have a compound message, made up of 
+    * multiple parts that are concatenated in a language-neutral way.
     * 
     * @return the arguments to this exception's message.
     */
@@ -204,8 +192,8 @@ public class InternationalizedException extends Exception {
    }
 
    /**
-    * Gets the <i>English</i> detail message for this exception. For the
-    * localized message use {@link #getLocalizedMessage()}.
+    * Gets the <i>English</i> detail message for this exception. For the localized message use 
+    * {@link #getLocalizedMessage()}.
     * 
     * @return the English detail message for this exception.
     */
@@ -214,9 +202,8 @@ public class InternationalizedException extends Exception {
    }
 
    /**
-    * Gets the localized detail message for this exception. This uses the
-    * default Locale for this JVM. A Locale may be specified using
-    * {@link #getLocalizedMessage(Locale)}.
+    * Gets the localized detail message for this exception. This uses the default Locale for this 
+    * JVM. A Locale may be specified using {@link #getLocalizedMessage(Locale)}.
     * 
     * @return this exception's detail message, localized for the default Locale.
     */
@@ -225,14 +212,12 @@ public class InternationalizedException extends Exception {
    }
 
    /**
-    * Gets the localized detail message for this exception using the specified
-    * <code>Locale</code>.
+    * Gets the localized detail message for this exception using the specified <code>Locale</code>.
     * 
     * @param aLocale
     *           the locale to use for localizing the message
     * 
-    * @return this exception's detail message, localized for the specified
-    *         <code>Locale</code>.
+    * @return this exception's detail message, localized for the specified <code>Locale</code>.
     */
    public String getLocalizedMessage(Locale aLocale) {
       // check for null message
@@ -268,8 +253,8 @@ public class InternationalizedException extends Exception {
    /**
     * Gets the cause of this Exception.
     * 
-    * @return the Throwable that caused this Exception to occur, if any. Returns
-    *         <code>null</code> if there is no such cause.
+    * @return the Throwable that caused this Exception to occur, if any. Returns <code>null</code> 
+    *         if there is no such cause.
     */
    public Throwable getCause() {
       return mCause;
