@@ -38,7 +38,6 @@ import org.apache.uima.analysis_engine.metadata.AnalysisEngineMetaData;
 import org.apache.uima.cas.AbstractCas;
 import org.apache.uima.cas.CAS;
 import org.apache.uima.cas.admin.CASMgr;
-import org.apache.uima.cas.impl.CASImpl;
 import org.apache.uima.collection.CasConsumerDescription;
 import org.apache.uima.impl.UimaContext_ImplBase;
 import org.apache.uima.impl.Util;
@@ -93,7 +92,7 @@ public class UimacppAnalysisEngineImpl extends AnalysisEngineImplBase implements
   private boolean mVerificationMode = false;
 
   /**
-   * @throws ResourceConfigurationException wrapping ResourceInitializationExceptions or 
+   * @throws ResourceInitializationException or 
    * wraps invalid xml exception when processing imports
    * @see org.apache.uima.resource.Resource#initialize(ResourceSpecifier, Map)
    */
@@ -259,6 +258,7 @@ public class UimacppAnalysisEngineImpl extends AnalysisEngineImplBase implements
    * 
    * @param aCAS
    *          CAS to be processed by annotator
+   * @throws AnalysisEngineProcessException -         
    */
   protected void callAnalysisComponentProcess(CAS aCAS) throws AnalysisEngineProcessException {
     // logging and instrumentation
@@ -372,6 +372,8 @@ public class UimacppAnalysisEngineImpl extends AnalysisEngineImplBase implements
    * Calls the Analysis Component's next() method.
    * 
    * @return CAS returned by the analysis component
+   * @throws AnalysisEngineProcessException -
+   * @throws ResultNotSupportedException -
    */
   protected CAS callAnalysisComponentNext() throws AnalysisEngineProcessException,
           ResultNotSupportedException {
@@ -404,6 +406,7 @@ public class UimacppAnalysisEngineImpl extends AnalysisEngineImplBase implements
 
   /**
    * @deprecated
+   * @return -
    */
   @Deprecated
   protected AnalysisProcessData_impl createAnalysisProcessData() {
