@@ -19,8 +19,9 @@
 
 package org.apache.uima.cas.impl;
 
+import java.util.Comparator;
+
 import org.apache.uima.cas.CAS;
-import org.apache.uima.cas.FSIndex;
 import org.apache.uima.cas.FSIterator;
 import org.apache.uima.cas.Feature;
 import org.apache.uima.cas.FeatureStructure;
@@ -36,11 +37,11 @@ import org.apache.uima.internal.util.IntVector;
  * The common (among all index kinds - set, sorted, bag) info for an index
  * Subtypes define the actual index repository (integers indexing the CAS) for each kind.
  * 
- * 
+ * @param <T> the Java cover class type for this index, passed along to (wrapped) iterators producing Java cover classes
  */
-public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements IntComparator, FSIndex<T>, FSIndexImpl {
+public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Comparator<T>, IntComparator, FSIndexImpl {
 
-  private final int indexType;
+  private final int indexType;  // Sorted, Set, Bag, Default-bag, etc.
 
   // A reference to the low-level CAS.
   final protected CASImpl lowLevelCAS;
@@ -84,6 +85,8 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
   private int numKeys;
 
   final private Type type; // The type of this
+  
+  final private int typeCode;
 
   
   
@@ -120,6 +123,7 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
     this.indexType = 0; // must do because it's final
     this.lowLevelCAS = null;
     this.type = null;
+    this.typeCode = 0;
   }
 
   /**
@@ -133,6 +137,7 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
     this.indexType = indexType;
     this.lowLevelCAS = cas;
     this.type = type;
+    this.typeCode = ((TypeImpl)type).getCode();
   }
 
   abstract boolean insert(int fs);
@@ -140,7 +145,10 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
   abstract boolean insert(int fs, int count);  // for bulk addback
 
   /**
-   * @param fs -
+   * @param fs - the Feature Structure to be removed.
+   * Only this exact Feature Structure is removed (this is a stronger test than, for example,
+   * what moveTo(fs) does, where the fs in that case is used as a template).  
+   * It is not an error if this exact Feature Structure is not in an index.
    * @return true if something was removed, false if not found
    */
   abstract boolean remove(int fs);
@@ -149,7 +157,7 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
 
   // public abstract ComparableIntIterator iterator(IntComparator comp);
 
-  public abstract ComparableIntPointerIterator pointerIterator(IntComparator comp,
+  public abstract ComparableIntPointerIterator<T> pointerIterator(IntComparator comp,
           int[] detectIllegalIndexUpdates, int typeCode);
 
   public FSIndexComparator getComparator() {
@@ -240,10 +248,22 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
     return this.comparator.getLowLevelCAS().getFeatureOffset(((FeatureImpl) feat).getCode());
   }
 
-  public int ll_compare(int ref1, int ref2) {
-    return this.compare(ref1, ref2);
+  /**
+   * Note: may return other than -1 , 0, and 1  (e.g., might return -6)
+   * @param fs1 -
+   * @param fs2 -
+   * @return 0 if equal, &lt; 0 if fs1 &lt; fs2, &gt; 0 if fs1 &gt; fs2
+   */
+  public int ll_compare(int fs1, int fs2) {
+    return this.compare(fs1, fs2);
   }
 
+  /**
+   * Note: may return other than -1 , 0, and 1  (e.g., might return -6)
+   * @param fs1 -
+   * @param fs2 -
+   * @return 0 if equal, &lt; 0 if fs1 &lt; fs2, &gt; 0 if fs1 &gt; fs2
+   */
   public int compare(int fs1, int fs2) {
     final int[] heap = this.lowLevelCAS.getHeap().heap;
     final int[] localKeyType = this.keyType;
@@ -420,7 +440,7 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
       return false;
     if (getClass() != obj.getClass())
       return false;
-    FSLeafIndexImpl other = (FSLeafIndexImpl) obj;
+    FSLeafIndexImpl<?> other = (FSLeafIndexImpl<?>) obj;
     if (comparator == null) {
       if (other.comparator != null)
         return false;
@@ -439,10 +459,15 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
 
   /**
    * @see org.apache.uima.cas.FSIndex#getType()
+   * @return The type of feature structures in this index.
    */
   public Type getType() {
     return this.type;
   }
+  
+  int getTypeCode() {
+    return this.typeCode;
+  }
 
   protected abstract IntPointerIterator refIterator();
 
@@ -452,7 +477,7 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
 
   /**
    * For serialization: get all the items in this index and bulk add to an IntVector
-   * @param v
+   * @param v the set of items to add
    */
   protected abstract void bulkAddTo(IntVector v);
   
@@ -465,15 +490,21 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
   // It would be good to refactor this so that this confusion is eliminated,
   // perhaps by not having this class implement FSIndex
 
-  /**
-   * @see org.apache.uima.cas.FSIndex#iterator()
-   */
-  public FSIterator<T> iterator() {
-    return new FSIteratorWrapper<T>(refIterator(), this.lowLevelCAS);
-  }
+//  /**
+//   * @see org.apache.uima.cas.FSIndex#iterator()
+//   */
+//  public FSIterator<T> iterator() {
+//    return new FSIteratorWrapper<T>(refIterator(), this.lowLevelCAS);
+//  }
 
   /**
    * @see org.apache.uima.cas.FSIndex#iterator(FeatureStructure)
+   * 
+   * This has no callers, and is probably not used.
+   * The iterator it produces is only over one leaf index and
+   * doesn't include Concurrent Modification Exception testing
+   * @param fs -
+   * @return -
    */
   public FSIterator<T> iterator(FeatureStructure fs) {
     return new FSIteratorWrapper<T>(refIterator(((FeatureStructureImpl) fs).getAddress()),
@@ -499,14 +530,12 @@ public abstract class FSLeafIndexImpl<T extends FeatureStructure> implements Int
       return this.ll_iterator();
   }
 
-  @Override
-  public FSIndex withSnapshotIterators() {
-    // should never be called
-    // this is an artifact of the fact that FSLeafIndexImpl implements FSIndex interface
-    //   which seems incorrect?
-    throw new UnsupportedOperationException();
-  }
-  
-  
+//  @Override
+//  public FSIndex<T> withSnapshotIterators() {
+//    // should never be called
+//    // this is an artifact of the fact that FSLeafIndexImpl implements FSIndex interface
+//    //   which seems incorrect?
+//    throw new UnsupportedOperationException();
+//  }
 
 }
