@@ -1819,7 +1819,7 @@ public class XmiCasDeserializer {
      */
     private void addOutOfTypeSystemFeature(OotsElementData ootsElem, String featName, List<String> featVals) {
       Iterator<String> iter = featVals.iterator();
-      XmlElementName elemName = new XmlElementName(null,featName,featName);
+      XmlElementName elemName = new XmlElementName("",featName,featName);
       while (iter.hasNext()) {
         ootsElem.childElements.add(new XmlElementNameAndContents(elemName, iter.next()));
       }
@@ -2009,7 +2009,7 @@ public class XmiCasDeserializer {
    * Deserializes a CAS from XMI.
    * 
    * @param aStream
-   *          input stream from which to read the XCMI document
+   *          input stream from which to read the XMI document
    * @param aCAS
    *          CAS into which to deserialize. This CAS must be set up with a type system that is
    *          compatible with that in the XMI
@@ -2035,7 +2035,7 @@ public class XmiCasDeserializer {
    * Deserializes a CAS from XMI.  This version of this method supports merging multiple XMI documents into a single CAS.
    * 
    * @param aStream
-   *          input stream from which to read the XCMI document
+   *          input stream from which to read the XMI document
    * @param aCAS
    *          CAS into which to deserialize. This CAS must be set up with a type system that is
    *          compatible with that in the XMI
@@ -2078,7 +2078,7 @@ public class XmiCasDeserializer {
    * 
    * 
    * @param aStream
-   *            input stream from which to read the XCMI document
+   *            input stream from which to read the XMI document
    * @param aCAS
    *            CAS into which to deserialize. This CAS must be set up with a
    *            type system that is compatible with that in the XMI
