@@ -29,13 +29,16 @@ import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
+import java.util.IdentityHashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
 import java.util.WeakHashMap;
 
+import org.apache.uima.UIMAFramework;
 import org.apache.uima.cas.AbstractCas;
 import org.apache.uima.cas.AbstractCas_ImplBase;
 import org.apache.uima.cas.CAS;
@@ -77,6 +80,8 @@ import org.apache.uima.jcas.cas.StringArray;
 import org.apache.uima.jcas.cas.TOP;
 import org.apache.uima.jcas.cas.TOP_Type;
 import org.apache.uima.jcas.tcas.Annotation;
+import org.apache.uima.util.Level;
+import org.apache.uima.util.Logger;
 
 // *********************************
 // * Implementation of JCas *
@@ -219,6 +224,15 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     }
   }
 
+  static public class ErrorReport {
+    final Exception e;
+    final boolean doThrow;
+    ErrorReport(Exception e, boolean doThrow) {
+      this.e = e;
+      this.doThrow = doThrow;
+    }
+  }
+
   // *************************************************
   // * Static Data shared with all instances of JCas *
   // *************************************************
@@ -283,7 +297,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
      */
     private JCasHashMap cAddr2Jfs;
 
-    private final Map<ClassLoader, JCasHashMap> cAddr2JfsByClassLoader = new HashMap<ClassLoader, JCasHashMap>();
+    private final Map<ClassLoader, JCasHashMap> cAddr2JfsByClassLoader = new IdentityHashMap<ClassLoader, JCasHashMap>();
 
     /* convenience holders of CAS constants that may be useful */
     /* initialization done lazily - on first call to getter */
@@ -297,9 +311,12 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     public FSArray fsArray0L = null;
 
     // * collection of errors that occur during initialization
-    public Collection<Exception> errorSet = new ArrayList<Exception>();
+    public Collection<ErrorReport> errorSet = new ArrayList<ErrorReport>();
 
     public ClassLoader currentClassLoader = null;
+    
+    private ClassLoader cacheClassLoaderInitialized;
+    final private Map<ClassLoader, Boolean> isInitializedForClassLoader = Collections.synchronizedMap(new IdentityHashMap<ClassLoader, Boolean>());
 
     private JCasSharedView(CASImpl aCAS, boolean useJcasCache) {
       setupJCasHashMap(aCAS.getJCasClassLoader(), useJcasCache, aCAS.getHeap().getInitialSize() / 16);
@@ -410,6 +427,10 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     return typeArray[i];
   }
   
+  /**
+   * Map from type codes to _Type instances kept per view in the field typeArray
+   * @param i
+   */
   private void getTypeInit(final int i) {
     // unknown ID. This may be due to a need to update the typeArray
     // due to switching class loaders. This updating is done
@@ -566,7 +587,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     // * note that many of these may have already been loaded
     // * load all the others. Actually, we ask to load all the types
     // * and the ones already loaded - we just get their loaded versions
-    // returned.
+    //   returned.
     // * Loading will run the static init functions.
 
     while (typeIt.hasNext()) {
@@ -577,8 +598,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
         continue;
       if (builtInsWithAltNames.contains(casName))
         // * convert uima.cas.Xxx -> org.apache.uima.jcas.cas.Xxx
-        // * convert uima.tcas.Annotator ->
-        // org.apache.uima.jcas.tcas.Annotator
+        // * convert uima.tcas.Annotator -> org.apache.uima.jcas.tcas.Annotator
         try {
           String nameBase = "org.apache.uima.jcas." + casName.substring(5);
           name_Type = nameBase + "_Type";
@@ -633,7 +653,29 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
       typeArray = newTypeArray;
     }
   }
+  
+  /**
+   * called when switching to JCas and the JCas already exists to check if 
+   * the JCas needs to have classes loaded for this class loader.  This can happen when the JCas is first
+   * instantiated while under the scope of a nested UIMA class loader.  This could be a Pear class loader, or
+   * even just an ordinary UIMA Class loader for a pipeline, where the Framework is running an "exit routine" supplied
+   * by the user, but loaded in a (for example) initial application loader context.
+   * @param cl the class loader in use
+   */
+  public void maybeInitializeForClassLoader(ClassLoader cl) {
+    if (sharedView.cacheClassLoaderInitialized == cl) {
+      return;
+    }
+    if (this.sharedView.isInitializedForClassLoader.get(cl) == null) {
+      instantiateJCas_Types(cl);
+    }
+    sharedView.cacheClassLoaderInitialized = cl;
+  }
 
+  /**
+   * 
+   * @param cl the class loader to use as the initiating loader for loading JCas classes
+   */
   public void instantiateJCas_Types(ClassLoader cl) {
     Map<String, LoadedJCasType<?>> loadedJCasTypes = null;
     FSClassRegistry fscr = casImpl.getFSClassRegistry();
@@ -656,11 +698,15 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
       // if already loaded, can skip making new generators - 
       //   in this case newFSGeneratorSet is never referenced
       //   Set it to null for "safety"
+      // If not already loaded, initialize the generators to a clone of the FSClassRegistry generators.
       newFSGeneratorSet = (alreadyLoaded ? null : fscr.getNewFSGeneratorSet());
       for (Iterator<Map.Entry<String, LoadedJCasType<?>>> it = loadedJCasTypes.entrySet().iterator(); it.hasNext();) {
         
         // Explanation for this logic:
         //   Instances of _Types are kept per class loader, per Cas (e.g., in the cas pool)
+        //     and per view (to support having the ref to the casImpl be to the right view
+        //                   so add-to-indexes works better).
+        //                   The "typeArray" field is per view.
         //   When switching class loaders (e.g. a pear in the pipeline), some of the 
         //     _Type instances (e.g. the built-ins) might be already instantiated, but others are not
         //   
@@ -670,7 +716,8 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
       }
       
       // speed up - skip rest if nothing to do
-      if (!anyNewInstances) {
+      if (!anyNewInstances && 
+          sharedView.isInitializedForClassLoader.get(cl) != null) {  // don't skip if need to install the new generators for this class loader UIMA-5055
         return;
       }
       if (!alreadyLoaded) {
@@ -686,6 +733,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     } else {
       casImpl.setLocalFsGenerators(newFSGeneratorSet);
     }
+    sharedView.isInitializedForClassLoader.put(cl, Boolean.TRUE);
   }
 
   // note all callers are synchronized
@@ -734,18 +782,34 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
    */
   public static JCas getJCas(CASImpl cas) throws CASException {
     JCasImpl jcas = new JCasImpl(cas);
+    reportInitErrors(jcas);
+    return jcas;
+  }
+  
+  private static void reportInitErrors(JCasImpl jcas) throws CASException {
     JCasSharedView sv = jcas.sharedView;
     if (sv.errorSet.size() > 0) {
+      boolean doThrow = false;
       StringBuffer msg = new StringBuffer(100);
-      for (Exception f : sv.errorSet) {
-        msg.append(f.getMessage());
+      msg.append('\n');
+      for (ErrorReport f : sv.errorSet) {
+        msg.append(f.e.getMessage());
         msg.append('\n');
+        doThrow = doThrow || f.doThrow;
+      }
+      if (doThrow) {
+        CASException e = new CASException(CASException.JCAS_INIT_ERROR,
+            new String[] { msg.toString() });
+        throw e;
+      } else {
+        Logger logger = UIMAFramework.getLogger();
+        if (null == logger) {
+          throw new CASRuntimeException(CASException.JCAS_INIT_ERROR, new String[] {msg.toString()});
+        } else {
+          logger.log(Level.WARNING, msg.toString());
+        }          
       }
-      CASException e = new CASException(CASException.JCAS_INIT_ERROR,
-          new String[] { msg.toString() });
-      throw e;
     }
-    return jcas;
   }
 
   /**
@@ -917,9 +981,11 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
    * Make the instance of the JCas xxx_Type class for this CAS. Note: not all types will have
    * xxx_Type. Instance creation does the typeSystemInit kind of function, as well.
    * 
-   * returns true if a new instance of a _Type class was created
+   * @param jcasTypeInfo -
+   * @param alreadyLoaded -
+   * @param fsGenerators updated by side effect with new instances of the _Type class
+   * @return true if a new instance of a _Type class was created
    */
-
   private <T extends TOP> boolean makeInstanceOf_Type(LoadedJCasType<T> jcasTypeInfo, boolean alreadyLoaded,
       FSGenerator<?>[] fsGenerators) {
     
@@ -930,8 +996,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
     //     instantiated _Type instances, but others may be different
     //     (due to different impls of the _Type class loaded by the different
     //     class loader).
-    //   This can also happen in the case where
-    //   JCasImpl.getType is called for a non-existing class
+    //   This can also happen in the case where JCasImpl.getType is called for a non-existing class.
     //     What happens in this case is that the getType code has to assume that
     //     perhaps none of the _Type instances were made for this JCas (yet), because
     //     these are created lazily - so it calls instantiateJCas_Types to make them.
@@ -1036,10 +1101,10 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
   public Feature getRequiredFeatureDE(Type t, String s, String rangeName, boolean featOkTst) {
     Feature f = t.getFeatureByBaseName(s);
     Type rangeType = this.getTypeSystem().getType(rangeName);
-    if (null == f && !featOkTst) {
+    if (null == f && featOkTst) {
       CASException casEx = new CASException(CASException.JCAS_FEATURENOTFOUND_ERROR, new String[] {
           t.getName(), s });
-      sharedView.errorSet.add(casEx);
+      sharedView.errorSet.add(new ErrorReport(casEx, false));  // false - no throw
     }
     if (null != f)
       try {
@@ -1047,7 +1112,7 @@ public class JCasImpl extends AbstractCas_ImplBase implements AbstractCas, JCas
       } catch (LowLevelException e) {
         CASException casEx = new CASException(CASException.JCAS_FEATURE_WRONG_TYPE, new String[] {
             t.getName(), s, rangeName, f.getRange().toString() });
-        sharedView.errorSet.add(casEx);
+        sharedView.errorSet.add(new ErrorReport(casEx, true));
       }
     return f;
   }
