@@ -49,6 +49,13 @@ import org.xml.sax.ext.LexicalHandler;
  * Utility class that generates XML output from SAX events or DOM nodes.
  */
 public class XMLSerializer {
+
+  // See Javadocs for javax.xml.transform.TransformerFactory for details on how the TransformerFactory is found:
+  //  the class specified in the system property: javax.xml.transform.TransformerFactory 
+  //  or the value of this property in <jre>/lib/jaxp.properties
+  //  or the class found in any jar that has an entry: META-INF/service/javax.xml.transform.TransformerFactory
+  //  or a platform default.
+  
   private static final SAXTransformerFactory transformerFactory = (SAXTransformerFactory) SAXTransformerFactory
           .newInstance();
 
@@ -73,6 +80,10 @@ public class XMLSerializer {
         mTransformer.setOutputProperty(OutputKeys.INDENT, "yes");
         mTransformer.setOutputProperty(OutputKeys.ENCODING, "UTF-8");
         mTransformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "4");
+        //   Saxon appears to ignore the above and use a default of 3 unless the following is used
+        //mTransformer.setOutputProperty("{http://saxon.sf.net/}indent-spaces", "4");
+        //   But this fails on Saxon9-HE with:
+        //     net.sf.saxon.trans.LicenseException: Requested feature (custom serialization) requires Saxon-PE
         mTransformer.setOutputProperty(OutputKeys.METHOD, "xml");
       }
 
@@ -365,12 +376,15 @@ public class XMLSerializer {
     private final void checkForInvalidXmlChars(String s, boolean xml11) throws SAXParseException {
       final int index = XMLUtils.checkForNonXmlCharacters(s, xml11);
       if (index >= 0) {
-        String msg =  String.format("Trying to serialize non-XML %s character: %c, 0x%x at offset %,d in string starting with %s",
-            (xml11 ? "1.1" : "1.0"),
-            s.charAt(index), 
-            (int)s.charAt(index),
-            index,
-            s.substring(0, Math.min(100,  s.length()))); 
+        String startStr = (index == 0) 
+            ? "[The Very First Character]"
+            : s.substring(0, Math.min(index, Math.min(100,  s.length())));
+        String msg =  String.format("Trying to serialize non-XML %s character: 0x%x at offset %,d in string starting with %s",
+                                      (xml11 ? "1.1" : "1.0"),
+//                                    s.charAt(index),  // don't try to output this, causes problems with other tooling 
+                                      (int)s.charAt(index),
+                                      index,
+                                      startStr); 
         throw new SAXParseException(msg, null);
       }
     }
@@ -378,12 +392,15 @@ public class XMLSerializer {
     private final void checkForInvalidXmlChars(char[] ch, int start, int length, boolean xml11) throws SAXParseException {
       final int index = XMLUtils.checkForNonXmlCharacters(ch, start, length, xml11);
       if (index >= 0) {
-        String msg =  String.format("Trying to serialize non-XML %s character: %c, 0x%x at offset %,d in string starting with %s",
+        String startStr = (index == 0) 
+            ? "[The Very First Character]"
+            : new String(ch).substring(0, Math.min(index, Math.min(100,  ch.length)));
+        String msg =  String.format("Trying to serialize non-XML %s character: 0x%x at offset %,d in string starting with %s",
             (xml11 ? "1.1" : "1.0"),
-            ch[index], 
+//            ch[index],  // don't try to output this, causes problems with other tooling  
             (int)(ch[index]),
             index,
-            (new String(ch)).substring(0, Math.min(100,  ch.length))); 
+            startStr); 
         throw new SAXParseException(msg, null);
       }
     }
